campuses

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for campuses API.

func (*Client) GetCampusesID

func (a *Client) GetCampusesID(params *GetCampusesIDParams, opts ...ClientOption) (*GetCampusesIDOK, error)

GetCampusesID gets a campus by ID.

get a single campus by its ID.

This method does not support injected context. However, timeout and opentracing contexts are honored whenever enabled.

If you need to pass a specific context, use Client.GetCampusesIDContext instead.

func (*Client) GetCampusesIDContext

func (a *Client) GetCampusesIDContext(ctx context.Context, params *GetCampusesIDParams, opts ...ClientOption) (*GetCampusesIDOK, error)

GetCampusesIDContext gets a campus by ID.

get a single campus by its ID.

Do not use the deprecated [GetCampusesIDParams.Context] with this method: it would be ignored.

func (*Client) GetCollegesCollegeIDCampuses

func (a *Client) GetCollegesCollegeIDCampuses(params *GetCollegesCollegeIDCampusesParams, opts ...ClientOption) (*GetCollegesCollegeIDCampusesOK, error)

GetCollegesCollegeIDCampuses gets campuses by college ID.

get all campuses by college ID or a campus by college ID with specified name.

This method does not support injected context. However, timeout and opentracing contexts are honored whenever enabled.

If you need to pass a specific context, use Client.GetCollegesCollegeIDCampusesContext instead.

func (*Client) GetCollegesCollegeIDCampusesContext

func (a *Client) GetCollegesCollegeIDCampusesContext(ctx context.Context, params *GetCollegesCollegeIDCampusesParams, opts ...ClientOption) (*GetCollegesCollegeIDCampusesOK, error)

GetCollegesCollegeIDCampusesContext gets campuses by college ID.

get all campuses by college ID or a campus by college ID with specified name.

Do not use the deprecated [GetCollegesCollegeIDCampusesParams.Context] with this method: it would be ignored.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ContextualTransport)

SetTransport changes the transport on the client

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

type ClientService

type ClientService interface {

	// GetCampusesID get a campus by ID.
	GetCampusesID(params *GetCampusesIDParams, opts ...ClientOption) (*GetCampusesIDOK, error)

	// GetCampusesIDContext get a campus by ID.
	GetCampusesIDContext(ctx context.Context, params *GetCampusesIDParams, opts ...ClientOption) (*GetCampusesIDOK, error)

	// GetCollegesCollegeIDCampuses get campuses by college ID.
	GetCollegesCollegeIDCampuses(params *GetCollegesCollegeIDCampusesParams, opts ...ClientOption) (*GetCollegesCollegeIDCampusesOK, error)

	// GetCollegesCollegeIDCampusesContext get campuses by college ID.
	GetCollegesCollegeIDCampusesContext(ctx context.Context, params *GetCollegesCollegeIDCampusesParams, opts ...ClientOption) (*GetCollegesCollegeIDCampusesOK, error)

	SetTransport(transport runtime.ContextualTransport)
}

ClientService is the interface for Client methods.

func New

New creates a new campuses API client.

func NewClientWithBasicAuth

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new campuses API client with basic auth credentials.

It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new campuses API client with a bearer token for authentication.

It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

type GetCampusesIDBadRequest

type GetCampusesIDBadRequest struct {
	Payload *models.DtoErrorResponse
}

GetCampusesIDBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewGetCampusesIDBadRequest

func NewGetCampusesIDBadRequest() *GetCampusesIDBadRequest

NewGetCampusesIDBadRequest creates a GetCampusesIDBadRequest with default headers values

func (*GetCampusesIDBadRequest) Code

func (o *GetCampusesIDBadRequest) Code() int

Code gets the status code for the get campuses Id bad request response

func (*GetCampusesIDBadRequest) Error

func (o *GetCampusesIDBadRequest) Error() string

func (*GetCampusesIDBadRequest) GetPayload

func (*GetCampusesIDBadRequest) IsClientError

func (o *GetCampusesIDBadRequest) IsClientError() bool

IsClientError returns true when this get campuses Id bad request response has a 4xx status code

func (*GetCampusesIDBadRequest) IsCode

func (o *GetCampusesIDBadRequest) IsCode(code int) bool

IsCode returns true when this get campuses Id bad request response a status code equal to that given

func (*GetCampusesIDBadRequest) IsRedirect

func (o *GetCampusesIDBadRequest) IsRedirect() bool

IsRedirect returns true when this get campuses Id bad request response has a 3xx status code

func (*GetCampusesIDBadRequest) IsServerError

func (o *GetCampusesIDBadRequest) IsServerError() bool

IsServerError returns true when this get campuses Id bad request response has a 5xx status code

func (*GetCampusesIDBadRequest) IsSuccess

func (o *GetCampusesIDBadRequest) IsSuccess() bool

IsSuccess returns true when this get campuses Id bad request response has a 2xx status code

func (*GetCampusesIDBadRequest) String

func (o *GetCampusesIDBadRequest) String() string

type GetCampusesIDInternalServerError

type GetCampusesIDInternalServerError struct {
	Payload *models.DtoErrorResponse
}

GetCampusesIDInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewGetCampusesIDInternalServerError

func NewGetCampusesIDInternalServerError() *GetCampusesIDInternalServerError

NewGetCampusesIDInternalServerError creates a GetCampusesIDInternalServerError with default headers values

func (*GetCampusesIDInternalServerError) Code

Code gets the status code for the get campuses Id internal server error response

func (*GetCampusesIDInternalServerError) Error

func (*GetCampusesIDInternalServerError) GetPayload

func (*GetCampusesIDInternalServerError) IsClientError

func (o *GetCampusesIDInternalServerError) IsClientError() bool

IsClientError returns true when this get campuses Id internal server error response has a 4xx status code

func (*GetCampusesIDInternalServerError) IsCode

func (o *GetCampusesIDInternalServerError) IsCode(code int) bool

IsCode returns true when this get campuses Id internal server error response a status code equal to that given

func (*GetCampusesIDInternalServerError) IsRedirect

func (o *GetCampusesIDInternalServerError) IsRedirect() bool

IsRedirect returns true when this get campuses Id internal server error response has a 3xx status code

func (*GetCampusesIDInternalServerError) IsServerError

func (o *GetCampusesIDInternalServerError) IsServerError() bool

IsServerError returns true when this get campuses Id internal server error response has a 5xx status code

func (*GetCampusesIDInternalServerError) IsSuccess

func (o *GetCampusesIDInternalServerError) IsSuccess() bool

IsSuccess returns true when this get campuses Id internal server error response has a 2xx status code

func (*GetCampusesIDInternalServerError) String

type GetCampusesIDNotFound

type GetCampusesIDNotFound struct {
	Payload *models.DtoErrorResponse
}

GetCampusesIDNotFound describes a response with status code 404, with default header values.

Not Found

func NewGetCampusesIDNotFound

func NewGetCampusesIDNotFound() *GetCampusesIDNotFound

NewGetCampusesIDNotFound creates a GetCampusesIDNotFound with default headers values

func (*GetCampusesIDNotFound) Code

func (o *GetCampusesIDNotFound) Code() int

Code gets the status code for the get campuses Id not found response

func (*GetCampusesIDNotFound) Error

func (o *GetCampusesIDNotFound) Error() string

func (*GetCampusesIDNotFound) GetPayload

func (*GetCampusesIDNotFound) IsClientError

func (o *GetCampusesIDNotFound) IsClientError() bool

IsClientError returns true when this get campuses Id not found response has a 4xx status code

func (*GetCampusesIDNotFound) IsCode

func (o *GetCampusesIDNotFound) IsCode(code int) bool

IsCode returns true when this get campuses Id not found response a status code equal to that given

func (*GetCampusesIDNotFound) IsRedirect

func (o *GetCampusesIDNotFound) IsRedirect() bool

IsRedirect returns true when this get campuses Id not found response has a 3xx status code

func (*GetCampusesIDNotFound) IsServerError

func (o *GetCampusesIDNotFound) IsServerError() bool

IsServerError returns true when this get campuses Id not found response has a 5xx status code

func (*GetCampusesIDNotFound) IsSuccess

func (o *GetCampusesIDNotFound) IsSuccess() bool

IsSuccess returns true when this get campuses Id not found response has a 2xx status code

func (*GetCampusesIDNotFound) String

func (o *GetCampusesIDNotFound) String() string

type GetCampusesIDOK

type GetCampusesIDOK struct {
	Payload *models.DtoCampusResponse
}

GetCampusesIDOK describes a response with status code 200, with default header values.

OK

func NewGetCampusesIDOK

func NewGetCampusesIDOK() *GetCampusesIDOK

NewGetCampusesIDOK creates a GetCampusesIDOK with default headers values

func (*GetCampusesIDOK) Code

func (o *GetCampusesIDOK) Code() int

Code gets the status code for the get campuses Id o k response

func (*GetCampusesIDOK) Error

func (o *GetCampusesIDOK) Error() string

func (*GetCampusesIDOK) GetPayload

func (o *GetCampusesIDOK) GetPayload() *models.DtoCampusResponse

func (*GetCampusesIDOK) IsClientError

func (o *GetCampusesIDOK) IsClientError() bool

IsClientError returns true when this get campuses Id o k response has a 4xx status code

func (*GetCampusesIDOK) IsCode

func (o *GetCampusesIDOK) IsCode(code int) bool

IsCode returns true when this get campuses Id o k response a status code equal to that given

func (*GetCampusesIDOK) IsRedirect

func (o *GetCampusesIDOK) IsRedirect() bool

IsRedirect returns true when this get campuses Id o k response has a 3xx status code

func (*GetCampusesIDOK) IsServerError

func (o *GetCampusesIDOK) IsServerError() bool

IsServerError returns true when this get campuses Id o k response has a 5xx status code

func (*GetCampusesIDOK) IsSuccess

func (o *GetCampusesIDOK) IsSuccess() bool

IsSuccess returns true when this get campuses Id o k response has a 2xx status code

func (*GetCampusesIDOK) String

func (o *GetCampusesIDOK) String() string

type GetCampusesIDParams

type GetCampusesIDParams struct {

	// ID.
	//
	// Campus ID
	ID int64

	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetCampusesIDParams contains all the parameters to send to the API endpoint

for the get campuses ID operation.

Typically these are written to a http.Request.

func NewGetCampusesIDParams

func NewGetCampusesIDParams() *GetCampusesIDParams

NewGetCampusesIDParams creates a new GetCampusesIDParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetCampusesIDParamsWithContext deprecated

func NewGetCampusesIDParamsWithContext(ctx context.Context) *GetCampusesIDParams

NewGetCampusesIDParamsWithContext creates a new GetCampusesIDParams object with the ability to set a context for a request.

Deprecated: use the operation call with context to pass the context instead of GetCampusesIDParams.

func NewGetCampusesIDParamsWithHTTPClient

func NewGetCampusesIDParamsWithHTTPClient(client *http.Client) *GetCampusesIDParams

NewGetCampusesIDParamsWithHTTPClient creates a new GetCampusesIDParams object with the ability to set a custom HTTPClient for a request.

func NewGetCampusesIDParamsWithTimeout

func NewGetCampusesIDParamsWithTimeout(timeout time.Duration) *GetCampusesIDParams

NewGetCampusesIDParamsWithTimeout creates a new GetCampusesIDParams object with the ability to set a timeout on a request.

func (*GetCampusesIDParams) SetContext deprecated

func (o *GetCampusesIDParams) SetContext(ctx context.Context)

SetContext adds the context to the get campuses ID params.

Deprecated: use the operation call with context to pass the context instead of GetCampusesIDParams.

func (*GetCampusesIDParams) SetDefaults

func (o *GetCampusesIDParams) SetDefaults()

SetDefaults hydrates default values in the get campuses ID params (not the query body).

All values with no default are reset to their zero value.

func (*GetCampusesIDParams) SetHTTPClient

func (o *GetCampusesIDParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get campuses ID params.

func (*GetCampusesIDParams) SetID

func (o *GetCampusesIDParams) SetID(id int64)

SetID adds the id to the get campuses ID params.

func (*GetCampusesIDParams) SetTimeout

func (o *GetCampusesIDParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get campuses ID params.

func (*GetCampusesIDParams) WithContext deprecated

WithContext adds the context to the get campuses ID params.

Deprecated: use the operation call with context to pass the context instead of GetCampusesIDParams.

func (*GetCampusesIDParams) WithDefaults

func (o *GetCampusesIDParams) WithDefaults() *GetCampusesIDParams

WithDefaults hydrates default values in the get campuses ID params (not the query body).

All values with no default are reset to their zero value.

func (*GetCampusesIDParams) WithHTTPClient

func (o *GetCampusesIDParams) WithHTTPClient(client *http.Client) *GetCampusesIDParams

WithHTTPClient adds the HTTPClient to the get campuses ID params.

func (*GetCampusesIDParams) WithID

WithID adds the id to the get campuses ID params.

func (*GetCampusesIDParams) WithTimeout

func (o *GetCampusesIDParams) WithTimeout(timeout time.Duration) *GetCampusesIDParams

WithTimeout adds the timeout to the get campuses ID params.

func (*GetCampusesIDParams) WriteToRequest

func (o *GetCampusesIDParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a runtime.ClientRequest.

type GetCampusesIDReader

type GetCampusesIDReader struct {
	// contains filtered or unexported fields
}

GetCampusesIDReader is a Reader for the GetCampusesID structure.

func (*GetCampusesIDReader) ReadResponse

func (o *GetCampusesIDReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)

ReadResponse reads a server response into the received o.

type GetCollegesCollegeIDCampusesBadRequest

type GetCollegesCollegeIDCampusesBadRequest struct {
	Payload *models.DtoErrorResponse
}

GetCollegesCollegeIDCampusesBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewGetCollegesCollegeIDCampusesBadRequest

func NewGetCollegesCollegeIDCampusesBadRequest() *GetCollegesCollegeIDCampusesBadRequest

NewGetCollegesCollegeIDCampusesBadRequest creates a GetCollegesCollegeIDCampusesBadRequest with default headers values

func (*GetCollegesCollegeIDCampusesBadRequest) Code

Code gets the status code for the get colleges college Id campuses bad request response

func (*GetCollegesCollegeIDCampusesBadRequest) Error

func (*GetCollegesCollegeIDCampusesBadRequest) GetPayload

func (*GetCollegesCollegeIDCampusesBadRequest) IsClientError

func (o *GetCollegesCollegeIDCampusesBadRequest) IsClientError() bool

IsClientError returns true when this get colleges college Id campuses bad request response has a 4xx status code

func (*GetCollegesCollegeIDCampusesBadRequest) IsCode

IsCode returns true when this get colleges college Id campuses bad request response a status code equal to that given

func (*GetCollegesCollegeIDCampusesBadRequest) IsRedirect

IsRedirect returns true when this get colleges college Id campuses bad request response has a 3xx status code

func (*GetCollegesCollegeIDCampusesBadRequest) IsServerError

func (o *GetCollegesCollegeIDCampusesBadRequest) IsServerError() bool

IsServerError returns true when this get colleges college Id campuses bad request response has a 5xx status code

func (*GetCollegesCollegeIDCampusesBadRequest) IsSuccess

IsSuccess returns true when this get colleges college Id campuses bad request response has a 2xx status code

func (*GetCollegesCollegeIDCampusesBadRequest) String

type GetCollegesCollegeIDCampusesInternalServerError

type GetCollegesCollegeIDCampusesInternalServerError struct {
	Payload *models.DtoErrorResponse
}

GetCollegesCollegeIDCampusesInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewGetCollegesCollegeIDCampusesInternalServerError

func NewGetCollegesCollegeIDCampusesInternalServerError() *GetCollegesCollegeIDCampusesInternalServerError

NewGetCollegesCollegeIDCampusesInternalServerError creates a GetCollegesCollegeIDCampusesInternalServerError with default headers values

func (*GetCollegesCollegeIDCampusesInternalServerError) Code

Code gets the status code for the get colleges college Id campuses internal server error response

func (*GetCollegesCollegeIDCampusesInternalServerError) Error

func (*GetCollegesCollegeIDCampusesInternalServerError) GetPayload

func (*GetCollegesCollegeIDCampusesInternalServerError) IsClientError

IsClientError returns true when this get colleges college Id campuses internal server error response has a 4xx status code

func (*GetCollegesCollegeIDCampusesInternalServerError) IsCode

IsCode returns true when this get colleges college Id campuses internal server error response a status code equal to that given

func (*GetCollegesCollegeIDCampusesInternalServerError) IsRedirect

IsRedirect returns true when this get colleges college Id campuses internal server error response has a 3xx status code

func (*GetCollegesCollegeIDCampusesInternalServerError) IsServerError

IsServerError returns true when this get colleges college Id campuses internal server error response has a 5xx status code

func (*GetCollegesCollegeIDCampusesInternalServerError) IsSuccess

IsSuccess returns true when this get colleges college Id campuses internal server error response has a 2xx status code

func (*GetCollegesCollegeIDCampusesInternalServerError) String

type GetCollegesCollegeIDCampusesNotFound

type GetCollegesCollegeIDCampusesNotFound struct {
	Payload *models.DtoErrorResponse
}

GetCollegesCollegeIDCampusesNotFound describes a response with status code 404, with default header values.

Not Found

func NewGetCollegesCollegeIDCampusesNotFound

func NewGetCollegesCollegeIDCampusesNotFound() *GetCollegesCollegeIDCampusesNotFound

NewGetCollegesCollegeIDCampusesNotFound creates a GetCollegesCollegeIDCampusesNotFound with default headers values

func (*GetCollegesCollegeIDCampusesNotFound) Code

Code gets the status code for the get colleges college Id campuses not found response

func (*GetCollegesCollegeIDCampusesNotFound) Error

func (*GetCollegesCollegeIDCampusesNotFound) GetPayload

func (*GetCollegesCollegeIDCampusesNotFound) IsClientError

func (o *GetCollegesCollegeIDCampusesNotFound) IsClientError() bool

IsClientError returns true when this get colleges college Id campuses not found response has a 4xx status code

func (*GetCollegesCollegeIDCampusesNotFound) IsCode

IsCode returns true when this get colleges college Id campuses not found response a status code equal to that given

func (*GetCollegesCollegeIDCampusesNotFound) IsRedirect

IsRedirect returns true when this get colleges college Id campuses not found response has a 3xx status code

func (*GetCollegesCollegeIDCampusesNotFound) IsServerError

func (o *GetCollegesCollegeIDCampusesNotFound) IsServerError() bool

IsServerError returns true when this get colleges college Id campuses not found response has a 5xx status code

func (*GetCollegesCollegeIDCampusesNotFound) IsSuccess

IsSuccess returns true when this get colleges college Id campuses not found response has a 2xx status code

func (*GetCollegesCollegeIDCampusesNotFound) String

type GetCollegesCollegeIDCampusesOK

type GetCollegesCollegeIDCampusesOK struct {
	Payload []*models.DtoCampusResponse
}

GetCollegesCollegeIDCampusesOK describes a response with status code 200, with default header values.

OK

func NewGetCollegesCollegeIDCampusesOK

func NewGetCollegesCollegeIDCampusesOK() *GetCollegesCollegeIDCampusesOK

NewGetCollegesCollegeIDCampusesOK creates a GetCollegesCollegeIDCampusesOK with default headers values

func (*GetCollegesCollegeIDCampusesOK) Code

Code gets the status code for the get colleges college Id campuses o k response

func (*GetCollegesCollegeIDCampusesOK) Error

func (*GetCollegesCollegeIDCampusesOK) GetPayload

func (*GetCollegesCollegeIDCampusesOK) IsClientError

func (o *GetCollegesCollegeIDCampusesOK) IsClientError() bool

IsClientError returns true when this get colleges college Id campuses o k response has a 4xx status code

func (*GetCollegesCollegeIDCampusesOK) IsCode

func (o *GetCollegesCollegeIDCampusesOK) IsCode(code int) bool

IsCode returns true when this get colleges college Id campuses o k response a status code equal to that given

func (*GetCollegesCollegeIDCampusesOK) IsRedirect

func (o *GetCollegesCollegeIDCampusesOK) IsRedirect() bool

IsRedirect returns true when this get colleges college Id campuses o k response has a 3xx status code

func (*GetCollegesCollegeIDCampusesOK) IsServerError

func (o *GetCollegesCollegeIDCampusesOK) IsServerError() bool

IsServerError returns true when this get colleges college Id campuses o k response has a 5xx status code

func (*GetCollegesCollegeIDCampusesOK) IsSuccess

func (o *GetCollegesCollegeIDCampusesOK) IsSuccess() bool

IsSuccess returns true when this get colleges college Id campuses o k response has a 2xx status code

func (*GetCollegesCollegeIDCampusesOK) String

type GetCollegesCollegeIDCampusesParams

type GetCollegesCollegeIDCampusesParams struct {

	// CollegeID.
	//
	// College ID
	CollegeID int64

	// Name.
	//
	// Campus name
	Name *string

	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetCollegesCollegeIDCampusesParams contains all the parameters to send to the API endpoint

for the get colleges college ID campuses operation.

Typically these are written to a http.Request.

func NewGetCollegesCollegeIDCampusesParams

func NewGetCollegesCollegeIDCampusesParams() *GetCollegesCollegeIDCampusesParams

NewGetCollegesCollegeIDCampusesParams creates a new GetCollegesCollegeIDCampusesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetCollegesCollegeIDCampusesParamsWithContext deprecated

func NewGetCollegesCollegeIDCampusesParamsWithContext(ctx context.Context) *GetCollegesCollegeIDCampusesParams

NewGetCollegesCollegeIDCampusesParamsWithContext creates a new GetCollegesCollegeIDCampusesParams object with the ability to set a context for a request.

Deprecated: use the operation call with context to pass the context instead of GetCollegesCollegeIDCampusesParams.

func NewGetCollegesCollegeIDCampusesParamsWithHTTPClient

func NewGetCollegesCollegeIDCampusesParamsWithHTTPClient(client *http.Client) *GetCollegesCollegeIDCampusesParams

NewGetCollegesCollegeIDCampusesParamsWithHTTPClient creates a new GetCollegesCollegeIDCampusesParams object with the ability to set a custom HTTPClient for a request.

func NewGetCollegesCollegeIDCampusesParamsWithTimeout

func NewGetCollegesCollegeIDCampusesParamsWithTimeout(timeout time.Duration) *GetCollegesCollegeIDCampusesParams

NewGetCollegesCollegeIDCampusesParamsWithTimeout creates a new GetCollegesCollegeIDCampusesParams object with the ability to set a timeout on a request.

func (*GetCollegesCollegeIDCampusesParams) SetCollegeID

func (o *GetCollegesCollegeIDCampusesParams) SetCollegeID(collegeID int64)

SetCollegeID adds the collegeId to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) SetContext deprecated

SetContext adds the context to the get colleges college ID campuses params.

Deprecated: use the operation call with context to pass the context instead of GetCollegesCollegeIDCampusesParams.

func (*GetCollegesCollegeIDCampusesParams) SetDefaults

func (o *GetCollegesCollegeIDCampusesParams) SetDefaults()

SetDefaults hydrates default values in the get colleges college ID campuses params (not the query body).

All values with no default are reset to their zero value.

func (*GetCollegesCollegeIDCampusesParams) SetHTTPClient

func (o *GetCollegesCollegeIDCampusesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) SetName

func (o *GetCollegesCollegeIDCampusesParams) SetName(name *string)

SetName adds the name to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) SetTimeout

func (o *GetCollegesCollegeIDCampusesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) WithCollegeID

WithCollegeID adds the collegeID to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) WithContext deprecated

WithContext adds the context to the get colleges college ID campuses params.

Deprecated: use the operation call with context to pass the context instead of GetCollegesCollegeIDCampusesParams.

func (*GetCollegesCollegeIDCampusesParams) WithDefaults

WithDefaults hydrates default values in the get colleges college ID campuses params (not the query body).

All values with no default are reset to their zero value.

func (*GetCollegesCollegeIDCampusesParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) WithName

WithName adds the name to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) WithTimeout

WithTimeout adds the timeout to the get colleges college ID campuses params.

func (*GetCollegesCollegeIDCampusesParams) WriteToRequest

WriteToRequest writes these params to a runtime.ClientRequest.

type GetCollegesCollegeIDCampusesReader

type GetCollegesCollegeIDCampusesReader struct {
	// contains filtered or unexported fields
}

GetCollegesCollegeIDCampusesReader is a Reader for the GetCollegesCollegeIDCampuses structure.

func (*GetCollegesCollegeIDCampusesReader) ReadResponse

func (o *GetCollegesCollegeIDCampusesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)

ReadResponse reads a server response into the received o.

Jump to