schedules

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for schedules API.

func (*Client) GetGroupsGroupIDSchedules

func (a *Client) GetGroupsGroupIDSchedules(params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)

GetGroupsGroupIDSchedules gets schedules.

get schedules by group ID.

This method does not support injected context. However, timeout and opentracing contexts are honored whenever enabled.

If you need to pass a specific context, use Client.GetGroupsGroupIDSchedulesContext instead.

func (*Client) GetGroupsGroupIDSchedulesContext

func (a *Client) GetGroupsGroupIDSchedulesContext(ctx context.Context, params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)

GetGroupsGroupIDSchedulesContext gets schedules.

get schedules by group ID.

Do not use the deprecated [GetGroupsGroupIDSchedulesParams.Context] with this method: it would be ignored.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ContextualTransport)

SetTransport changes the transport on the client

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

type ClientService

type ClientService interface {

	// GetGroupsGroupIDSchedules get schedules.
	GetGroupsGroupIDSchedules(params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)

	// GetGroupsGroupIDSchedulesContext get schedules.
	GetGroupsGroupIDSchedulesContext(ctx context.Context, params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)

	SetTransport(transport runtime.ContextualTransport)
}

ClientService is the interface for Client methods.

func New

New creates a new schedules API client.

func NewClientWithBasicAuth

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new schedules API client with basic auth credentials.

It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new schedules API client with a bearer token for authentication.

It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

type GetGroupsGroupIDSchedulesBadRequest

type GetGroupsGroupIDSchedulesBadRequest struct {
	Payload *models.DtoErrorResponse
}

GetGroupsGroupIDSchedulesBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewGetGroupsGroupIDSchedulesBadRequest

func NewGetGroupsGroupIDSchedulesBadRequest() *GetGroupsGroupIDSchedulesBadRequest

NewGetGroupsGroupIDSchedulesBadRequest creates a GetGroupsGroupIDSchedulesBadRequest with default headers values

func (*GetGroupsGroupIDSchedulesBadRequest) Code

Code gets the status code for the get groups group Id schedules bad request response

func (*GetGroupsGroupIDSchedulesBadRequest) Error

func (*GetGroupsGroupIDSchedulesBadRequest) GetPayload

func (*GetGroupsGroupIDSchedulesBadRequest) IsClientError

func (o *GetGroupsGroupIDSchedulesBadRequest) IsClientError() bool

IsClientError returns true when this get groups group Id schedules bad request response has a 4xx status code

func (*GetGroupsGroupIDSchedulesBadRequest) IsCode

IsCode returns true when this get groups group Id schedules bad request response a status code equal to that given

func (*GetGroupsGroupIDSchedulesBadRequest) IsRedirect

func (o *GetGroupsGroupIDSchedulesBadRequest) IsRedirect() bool

IsRedirect returns true when this get groups group Id schedules bad request response has a 3xx status code

func (*GetGroupsGroupIDSchedulesBadRequest) IsServerError

func (o *GetGroupsGroupIDSchedulesBadRequest) IsServerError() bool

IsServerError returns true when this get groups group Id schedules bad request response has a 5xx status code

func (*GetGroupsGroupIDSchedulesBadRequest) IsSuccess

IsSuccess returns true when this get groups group Id schedules bad request response has a 2xx status code

func (*GetGroupsGroupIDSchedulesBadRequest) String

type GetGroupsGroupIDSchedulesConflict

type GetGroupsGroupIDSchedulesConflict struct {
	Payload *models.DtoErrorResponse
}

GetGroupsGroupIDSchedulesConflict describes a response with status code 409, with default header values.

Conflict

func NewGetGroupsGroupIDSchedulesConflict

func NewGetGroupsGroupIDSchedulesConflict() *GetGroupsGroupIDSchedulesConflict

NewGetGroupsGroupIDSchedulesConflict creates a GetGroupsGroupIDSchedulesConflict with default headers values

func (*GetGroupsGroupIDSchedulesConflict) Code

Code gets the status code for the get groups group Id schedules conflict response

func (*GetGroupsGroupIDSchedulesConflict) Error

func (*GetGroupsGroupIDSchedulesConflict) GetPayload

func (*GetGroupsGroupIDSchedulesConflict) IsClientError

func (o *GetGroupsGroupIDSchedulesConflict) IsClientError() bool

IsClientError returns true when this get groups group Id schedules conflict response has a 4xx status code

func (*GetGroupsGroupIDSchedulesConflict) IsCode

func (o *GetGroupsGroupIDSchedulesConflict) IsCode(code int) bool

IsCode returns true when this get groups group Id schedules conflict response a status code equal to that given

func (*GetGroupsGroupIDSchedulesConflict) IsRedirect

func (o *GetGroupsGroupIDSchedulesConflict) IsRedirect() bool

IsRedirect returns true when this get groups group Id schedules conflict response has a 3xx status code

func (*GetGroupsGroupIDSchedulesConflict) IsServerError

func (o *GetGroupsGroupIDSchedulesConflict) IsServerError() bool

IsServerError returns true when this get groups group Id schedules conflict response has a 5xx status code

func (*GetGroupsGroupIDSchedulesConflict) IsSuccess

func (o *GetGroupsGroupIDSchedulesConflict) IsSuccess() bool

IsSuccess returns true when this get groups group Id schedules conflict response has a 2xx status code

func (*GetGroupsGroupIDSchedulesConflict) String

type GetGroupsGroupIDSchedulesInternalServerError

type GetGroupsGroupIDSchedulesInternalServerError struct {
	Payload *models.DtoErrorResponse
}

GetGroupsGroupIDSchedulesInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewGetGroupsGroupIDSchedulesInternalServerError

func NewGetGroupsGroupIDSchedulesInternalServerError() *GetGroupsGroupIDSchedulesInternalServerError

NewGetGroupsGroupIDSchedulesInternalServerError creates a GetGroupsGroupIDSchedulesInternalServerError with default headers values

func (*GetGroupsGroupIDSchedulesInternalServerError) Code

Code gets the status code for the get groups group Id schedules internal server error response

func (*GetGroupsGroupIDSchedulesInternalServerError) Error

func (*GetGroupsGroupIDSchedulesInternalServerError) GetPayload

func (*GetGroupsGroupIDSchedulesInternalServerError) IsClientError

IsClientError returns true when this get groups group Id schedules internal server error response has a 4xx status code

func (*GetGroupsGroupIDSchedulesInternalServerError) IsCode

IsCode returns true when this get groups group Id schedules internal server error response a status code equal to that given

func (*GetGroupsGroupIDSchedulesInternalServerError) IsRedirect

IsRedirect returns true when this get groups group Id schedules internal server error response has a 3xx status code

func (*GetGroupsGroupIDSchedulesInternalServerError) IsServerError

IsServerError returns true when this get groups group Id schedules internal server error response has a 5xx status code

func (*GetGroupsGroupIDSchedulesInternalServerError) IsSuccess

IsSuccess returns true when this get groups group Id schedules internal server error response has a 2xx status code

func (*GetGroupsGroupIDSchedulesInternalServerError) String

type GetGroupsGroupIDSchedulesNotFound

type GetGroupsGroupIDSchedulesNotFound struct {
	Payload *models.DtoErrorResponse
}

GetGroupsGroupIDSchedulesNotFound describes a response with status code 404, with default header values.

Not Found

func NewGetGroupsGroupIDSchedulesNotFound

func NewGetGroupsGroupIDSchedulesNotFound() *GetGroupsGroupIDSchedulesNotFound

NewGetGroupsGroupIDSchedulesNotFound creates a GetGroupsGroupIDSchedulesNotFound with default headers values

func (*GetGroupsGroupIDSchedulesNotFound) Code

Code gets the status code for the get groups group Id schedules not found response

func (*GetGroupsGroupIDSchedulesNotFound) Error

func (*GetGroupsGroupIDSchedulesNotFound) GetPayload

func (*GetGroupsGroupIDSchedulesNotFound) IsClientError

func (o *GetGroupsGroupIDSchedulesNotFound) IsClientError() bool

IsClientError returns true when this get groups group Id schedules not found response has a 4xx status code

func (*GetGroupsGroupIDSchedulesNotFound) IsCode

func (o *GetGroupsGroupIDSchedulesNotFound) IsCode(code int) bool

IsCode returns true when this get groups group Id schedules not found response a status code equal to that given

func (*GetGroupsGroupIDSchedulesNotFound) IsRedirect

func (o *GetGroupsGroupIDSchedulesNotFound) IsRedirect() bool

IsRedirect returns true when this get groups group Id schedules not found response has a 3xx status code

func (*GetGroupsGroupIDSchedulesNotFound) IsServerError

func (o *GetGroupsGroupIDSchedulesNotFound) IsServerError() bool

IsServerError returns true when this get groups group Id schedules not found response has a 5xx status code

func (*GetGroupsGroupIDSchedulesNotFound) IsSuccess

func (o *GetGroupsGroupIDSchedulesNotFound) IsSuccess() bool

IsSuccess returns true when this get groups group Id schedules not found response has a 2xx status code

func (*GetGroupsGroupIDSchedulesNotFound) String

type GetGroupsGroupIDSchedulesOK

type GetGroupsGroupIDSchedulesOK struct {
	Payload []*models.DtoScheduleResponse
}

GetGroupsGroupIDSchedulesOK describes a response with status code 200, with default header values.

OK

func NewGetGroupsGroupIDSchedulesOK

func NewGetGroupsGroupIDSchedulesOK() *GetGroupsGroupIDSchedulesOK

NewGetGroupsGroupIDSchedulesOK creates a GetGroupsGroupIDSchedulesOK with default headers values

func (*GetGroupsGroupIDSchedulesOK) Code

func (o *GetGroupsGroupIDSchedulesOK) Code() int

Code gets the status code for the get groups group Id schedules o k response

func (*GetGroupsGroupIDSchedulesOK) Error

func (*GetGroupsGroupIDSchedulesOK) GetPayload

func (*GetGroupsGroupIDSchedulesOK) IsClientError

func (o *GetGroupsGroupIDSchedulesOK) IsClientError() bool

IsClientError returns true when this get groups group Id schedules o k response has a 4xx status code

func (*GetGroupsGroupIDSchedulesOK) IsCode

func (o *GetGroupsGroupIDSchedulesOK) IsCode(code int) bool

IsCode returns true when this get groups group Id schedules o k response a status code equal to that given

func (*GetGroupsGroupIDSchedulesOK) IsRedirect

func (o *GetGroupsGroupIDSchedulesOK) IsRedirect() bool

IsRedirect returns true when this get groups group Id schedules o k response has a 3xx status code

func (*GetGroupsGroupIDSchedulesOK) IsServerError

func (o *GetGroupsGroupIDSchedulesOK) IsServerError() bool

IsServerError returns true when this get groups group Id schedules o k response has a 5xx status code

func (*GetGroupsGroupIDSchedulesOK) IsSuccess

func (o *GetGroupsGroupIDSchedulesOK) IsSuccess() bool

IsSuccess returns true when this get groups group Id schedules o k response has a 2xx status code

func (*GetGroupsGroupIDSchedulesOK) String

func (o *GetGroupsGroupIDSchedulesOK) String() string

type GetGroupsGroupIDSchedulesParams

type GetGroupsGroupIDSchedulesParams struct {

	// Date.
	//
	// Specific date (dd-mm-yyyy)
	Date *string

	// Day.
	//
	// Relative day
	Day *string

	// GroupID.
	//
	// Group ID
	GroupID int64

	// Week.
	//
	// Week of schedules
	Week *string

	// Weekday.
	//
	// Weekday of schedules
	Weekday *string

	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetGroupsGroupIDSchedulesParams contains all the parameters to send to the API endpoint

for the get groups group ID schedules operation.

Typically these are written to a http.Request.

func NewGetGroupsGroupIDSchedulesParams

func NewGetGroupsGroupIDSchedulesParams() *GetGroupsGroupIDSchedulesParams

NewGetGroupsGroupIDSchedulesParams creates a new GetGroupsGroupIDSchedulesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetGroupsGroupIDSchedulesParamsWithContext deprecated

func NewGetGroupsGroupIDSchedulesParamsWithContext(ctx context.Context) *GetGroupsGroupIDSchedulesParams

NewGetGroupsGroupIDSchedulesParamsWithContext creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a context for a request.

Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.

func NewGetGroupsGroupIDSchedulesParamsWithHTTPClient

func NewGetGroupsGroupIDSchedulesParamsWithHTTPClient(client *http.Client) *GetGroupsGroupIDSchedulesParams

NewGetGroupsGroupIDSchedulesParamsWithHTTPClient creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a custom HTTPClient for a request.

func NewGetGroupsGroupIDSchedulesParamsWithTimeout

func NewGetGroupsGroupIDSchedulesParamsWithTimeout(timeout time.Duration) *GetGroupsGroupIDSchedulesParams

NewGetGroupsGroupIDSchedulesParamsWithTimeout creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a timeout on a request.

func (*GetGroupsGroupIDSchedulesParams) SetContext deprecated

func (o *GetGroupsGroupIDSchedulesParams) SetContext(ctx context.Context)

SetContext adds the context to the get groups group ID schedules params.

Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.

func (*GetGroupsGroupIDSchedulesParams) SetDate

func (o *GetGroupsGroupIDSchedulesParams) SetDate(date *string)

SetDate adds the date to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetDay

func (o *GetGroupsGroupIDSchedulesParams) SetDay(day *string)

SetDay adds the day to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetDefaults

func (o *GetGroupsGroupIDSchedulesParams) SetDefaults()

SetDefaults hydrates default values in the get groups group ID schedules params (not the query body).

All values with no default are reset to their zero value.

func (*GetGroupsGroupIDSchedulesParams) SetGroupID

func (o *GetGroupsGroupIDSchedulesParams) SetGroupID(groupID int64)

SetGroupID adds the groupId to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetHTTPClient

func (o *GetGroupsGroupIDSchedulesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetTimeout

func (o *GetGroupsGroupIDSchedulesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetWeek

func (o *GetGroupsGroupIDSchedulesParams) SetWeek(week *string)

SetWeek adds the week to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) SetWeekday

func (o *GetGroupsGroupIDSchedulesParams) SetWeekday(weekday *string)

SetWeekday adds the weekday to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithContext deprecated

WithContext adds the context to the get groups group ID schedules params.

Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.

func (*GetGroupsGroupIDSchedulesParams) WithDate

WithDate adds the date to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithDay

WithDay adds the day to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithDefaults

WithDefaults hydrates default values in the get groups group ID schedules params (not the query body).

All values with no default are reset to their zero value.

func (*GetGroupsGroupIDSchedulesParams) WithGroupID

WithGroupID adds the groupID to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithTimeout

WithTimeout adds the timeout to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithWeek

WithWeek adds the week to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WithWeekday

WithWeekday adds the weekday to the get groups group ID schedules params.

func (*GetGroupsGroupIDSchedulesParams) WriteToRequest

WriteToRequest writes these params to a runtime.ClientRequest.

type GetGroupsGroupIDSchedulesReader

type GetGroupsGroupIDSchedulesReader struct {
	// contains filtered or unexported fields
}

GetGroupsGroupIDSchedulesReader is a Reader for the GetGroupsGroupIDSchedules structure.

func (*GetGroupsGroupIDSchedulesReader) ReadResponse

func (o *GetGroupsGroupIDSchedulesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)

ReadResponse reads a server response into the received o.

Jump to