models

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DtoCall

type DtoCall any

DtoCall dto call

swagger:model dto.Call

type DtoCampusResponse

type DtoCampusResponse struct {

	// campus Id
	CampusID int64 `json:"campusId,omitempty"`

	// groups
	Groups []*DtoStudentGroupResponse `json:"groups"`

	// name
	Name string `json:"name,omitempty"`
}

DtoCampusResponse dto campus response

swagger:model dto.CampusResponse

func (*DtoCampusResponse) ContextValidate

func (m *DtoCampusResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this dto campus response based on the context it is used

func (*DtoCampusResponse) MarshalBinary

func (m *DtoCampusResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoCampusResponse) UnmarshalBinary

func (m *DtoCampusResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoCampusResponse) Validate

func (m *DtoCampusResponse) Validate(formats strfmt.Registry) error

Validate validates this dto campus response

type DtoCollegeResponse

type DtoCollegeResponse struct {

	// campuses
	Campuses []*DtoCampusResponse `json:"campuses"`

	// college Id
	CollegeID int64 `json:"collegeId,omitempty"`

	// name
	Name string `json:"name,omitempty"`
}

DtoCollegeResponse dto college response

swagger:model dto.CollegeResponse

func (*DtoCollegeResponse) ContextValidate

func (m *DtoCollegeResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this dto college response based on the context it is used

func (*DtoCollegeResponse) MarshalBinary

func (m *DtoCollegeResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoCollegeResponse) UnmarshalBinary

func (m *DtoCollegeResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoCollegeResponse) Validate

func (m *DtoCollegeResponse) Validate(formats strfmt.Registry) error

Validate validates this dto college response

type DtoErrorResponse

type DtoErrorResponse struct {

	// error
	Error string `json:"error,omitempty"`

	// status code
	StatusCode int64 `json:"statusCode,omitempty"`
}

DtoErrorResponse dto error response

swagger:model dto.ErrorResponse

func (*DtoErrorResponse) ContextValidate

func (m *DtoErrorResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto error response based on context it is used

func (*DtoErrorResponse) MarshalBinary

func (m *DtoErrorResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoErrorResponse) UnmarshalBinary

func (m *DtoErrorResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoErrorResponse) Validate

func (m *DtoErrorResponse) Validate(formats strfmt.Registry) error

Validate validates this dto error response

type DtoGetParserResponse

type DtoGetParserResponse struct {

	// college Id
	CollegeID int64 `json:"collegeId,omitempty"`
}

DtoGetParserResponse dto get parser response

swagger:model dto.GetParserResponse

func (*DtoGetParserResponse) ContextValidate

func (m *DtoGetParserResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto get parser response based on context it is used

func (*DtoGetParserResponse) MarshalBinary

func (m *DtoGetParserResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoGetParserResponse) UnmarshalBinary

func (m *DtoGetParserResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoGetParserResponse) Validate

func (m *DtoGetParserResponse) Validate(formats strfmt.Registry) error

Validate validates this dto get parser response

type DtoLesson

type DtoLesson struct {

	// cabinet
	Cabinet string `json:"cabinet,omitempty"`

	// date
	Date string `json:"date,omitempty"`

	// lesson Id
	LessonID int64 `json:"lessonId,omitempty"`

	// order
	Order int64 `json:"order,omitempty"`

	// student group ID
	StudentGroupID int64 `json:"studentGroupID,omitempty"`

	// teacher
	Teacher string `json:"teacher,omitempty"`

	// title
	Title string `json:"title,omitempty"`
}

DtoLesson dto lesson

swagger:model dto.Lesson

func (*DtoLesson) ContextValidate

func (m *DtoLesson) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto lesson based on context it is used

func (*DtoLesson) MarshalBinary

func (m *DtoLesson) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoLesson) UnmarshalBinary

func (m *DtoLesson) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoLesson) Validate

func (m *DtoLesson) Validate(formats strfmt.Registry) error

Validate validates this dto lesson

type DtoNewParserRequest

type DtoNewParserRequest struct {

	// campus names
	CampusNames []string `json:"campusNames"`

	// college name
	CollegeName string `json:"collegeName,omitempty"`
}

DtoNewParserRequest dto new parser request

swagger:model dto.NewParserRequest

func (*DtoNewParserRequest) ContextValidate

func (m *DtoNewParserRequest) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto new parser request based on context it is used

func (*DtoNewParserRequest) MarshalBinary

func (m *DtoNewParserRequest) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoNewParserRequest) UnmarshalBinary

func (m *DtoNewParserRequest) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoNewParserRequest) Validate

func (m *DtoNewParserRequest) Validate(formats strfmt.Registry) error

Validate validates this dto new parser request

type DtoNewParserResponse

type DtoNewParserResponse struct {

	// token
	Token string `json:"token,omitempty"`
}

DtoNewParserResponse dto new parser response

swagger:model dto.NewParserResponse

func (*DtoNewParserResponse) ContextValidate

func (m *DtoNewParserResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto new parser response based on context it is used

func (*DtoNewParserResponse) MarshalBinary

func (m *DtoNewParserResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoNewParserResponse) UnmarshalBinary

func (m *DtoNewParserResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoNewParserResponse) Validate

func (m *DtoNewParserResponse) Validate(formats strfmt.Registry) error

Validate validates this dto new parser response

type DtoScheduleLessonResponse

type DtoScheduleLessonResponse struct {

	// cabinet
	Cabinet string `json:"cabinet,omitempty"`

	// end time
	EndTime string `json:"endTime,omitempty"`

	// order
	Order int64 `json:"order,omitempty"`

	// start time
	StartTime string `json:"startTime,omitempty"`

	// teacher
	Teacher string `json:"teacher,omitempty"`

	// title
	Title string `json:"title,omitempty"`
}

DtoScheduleLessonResponse dto schedule lesson response

swagger:model dto.ScheduleLessonResponse

func (*DtoScheduleLessonResponse) ContextValidate

func (m *DtoScheduleLessonResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto schedule lesson response based on context it is used

func (*DtoScheduleLessonResponse) MarshalBinary

func (m *DtoScheduleLessonResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoScheduleLessonResponse) UnmarshalBinary

func (m *DtoScheduleLessonResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoScheduleLessonResponse) Validate

func (m *DtoScheduleLessonResponse) Validate(formats strfmt.Registry) error

Validate validates this dto schedule lesson response

type DtoScheduleResponse

type DtoScheduleResponse struct {

	// date
	Date string `json:"date,omitempty"`

	// group Id
	GroupID int64 `json:"groupId,omitempty"`

	// lessons
	Lessons []*DtoScheduleLessonResponse `json:"lessons"`
}

DtoScheduleResponse dto schedule response

swagger:model dto.ScheduleResponse

func (*DtoScheduleResponse) ContextValidate

func (m *DtoScheduleResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this dto schedule response based on the context it is used

func (*DtoScheduleResponse) MarshalBinary

func (m *DtoScheduleResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoScheduleResponse) UnmarshalBinary

func (m *DtoScheduleResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoScheduleResponse) Validate

func (m *DtoScheduleResponse) Validate(formats strfmt.Registry) error

Validate validates this dto schedule response

type DtoStudentGroupResponse

type DtoStudentGroupResponse struct {

	// campus Id
	CampusID int64 `json:"campusId,omitempty"`

	// name
	Name string `json:"name,omitempty"`

	// student group Id
	StudentGroupID int64 `json:"studentGroupId,omitempty"`
}

DtoStudentGroupResponse dto student group response

swagger:model dto.StudentGroupResponse

func (*DtoStudentGroupResponse) ContextValidate

func (m *DtoStudentGroupResponse) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto student group response based on context it is used

func (*DtoStudentGroupResponse) MarshalBinary

func (m *DtoStudentGroupResponse) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoStudentGroupResponse) UnmarshalBinary

func (m *DtoStudentGroupResponse) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoStudentGroupResponse) Validate

func (m *DtoStudentGroupResponse) Validate(formats strfmt.Registry) error

Validate validates this dto student group response

type DtoUpdateGroupsRequest

type DtoUpdateGroupsRequest struct {

	// campus Id
	CampusID int64 `json:"campusId,omitempty"`

	// student group names
	StudentGroupNames []string `json:"studentGroupNames"`
}

DtoUpdateGroupsRequest dto update groups request

swagger:model dto.UpdateGroupsRequest

func (*DtoUpdateGroupsRequest) ContextValidate

func (m *DtoUpdateGroupsRequest) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this dto update groups request based on context it is used

func (*DtoUpdateGroupsRequest) MarshalBinary

func (m *DtoUpdateGroupsRequest) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DtoUpdateGroupsRequest) UnmarshalBinary

func (m *DtoUpdateGroupsRequest) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DtoUpdateGroupsRequest) Validate

func (m *DtoUpdateGroupsRequest) Validate(formats strfmt.Registry) error

Validate validates this dto update groups request

Jump to