Documentation
¶
Index ¶
- type Client
- func (a *Client) GetGroupsGroupIDSchedules(params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)
- func (a *Client) GetGroupsGroupIDSchedulesContext(ctx context.Context, params *GetGroupsGroupIDSchedulesParams, ...) (*GetGroupsGroupIDSchedulesOK, error)
- func (a *Client) SetTransport(transport runtime.ContextualTransport)
- type ClientOption
- type ClientService
- type GetGroupsGroupIDSchedulesBadRequest
- func (o *GetGroupsGroupIDSchedulesBadRequest) Code() int
- func (o *GetGroupsGroupIDSchedulesBadRequest) Error() string
- func (o *GetGroupsGroupIDSchedulesBadRequest) GetPayload() *models.DtoErrorResponse
- func (o *GetGroupsGroupIDSchedulesBadRequest) IsClientError() bool
- func (o *GetGroupsGroupIDSchedulesBadRequest) IsCode(code int) bool
- func (o *GetGroupsGroupIDSchedulesBadRequest) IsRedirect() bool
- func (o *GetGroupsGroupIDSchedulesBadRequest) IsServerError() bool
- func (o *GetGroupsGroupIDSchedulesBadRequest) IsSuccess() bool
- func (o *GetGroupsGroupIDSchedulesBadRequest) String() string
- type GetGroupsGroupIDSchedulesConflict
- func (o *GetGroupsGroupIDSchedulesConflict) Code() int
- func (o *GetGroupsGroupIDSchedulesConflict) Error() string
- func (o *GetGroupsGroupIDSchedulesConflict) GetPayload() *models.DtoErrorResponse
- func (o *GetGroupsGroupIDSchedulesConflict) IsClientError() bool
- func (o *GetGroupsGroupIDSchedulesConflict) IsCode(code int) bool
- func (o *GetGroupsGroupIDSchedulesConflict) IsRedirect() bool
- func (o *GetGroupsGroupIDSchedulesConflict) IsServerError() bool
- func (o *GetGroupsGroupIDSchedulesConflict) IsSuccess() bool
- func (o *GetGroupsGroupIDSchedulesConflict) String() string
- type GetGroupsGroupIDSchedulesInternalServerError
- func (o *GetGroupsGroupIDSchedulesInternalServerError) Code() int
- func (o *GetGroupsGroupIDSchedulesInternalServerError) Error() string
- func (o *GetGroupsGroupIDSchedulesInternalServerError) GetPayload() *models.DtoErrorResponse
- func (o *GetGroupsGroupIDSchedulesInternalServerError) IsClientError() bool
- func (o *GetGroupsGroupIDSchedulesInternalServerError) IsCode(code int) bool
- func (o *GetGroupsGroupIDSchedulesInternalServerError) IsRedirect() bool
- func (o *GetGroupsGroupIDSchedulesInternalServerError) IsServerError() bool
- func (o *GetGroupsGroupIDSchedulesInternalServerError) IsSuccess() bool
- func (o *GetGroupsGroupIDSchedulesInternalServerError) String() string
- type GetGroupsGroupIDSchedulesNotFound
- func (o *GetGroupsGroupIDSchedulesNotFound) Code() int
- func (o *GetGroupsGroupIDSchedulesNotFound) Error() string
- func (o *GetGroupsGroupIDSchedulesNotFound) GetPayload() *models.DtoErrorResponse
- func (o *GetGroupsGroupIDSchedulesNotFound) IsClientError() bool
- func (o *GetGroupsGroupIDSchedulesNotFound) IsCode(code int) bool
- func (o *GetGroupsGroupIDSchedulesNotFound) IsRedirect() bool
- func (o *GetGroupsGroupIDSchedulesNotFound) IsServerError() bool
- func (o *GetGroupsGroupIDSchedulesNotFound) IsSuccess() bool
- func (o *GetGroupsGroupIDSchedulesNotFound) String() string
- type GetGroupsGroupIDSchedulesOK
- func (o *GetGroupsGroupIDSchedulesOK) Code() int
- func (o *GetGroupsGroupIDSchedulesOK) Error() string
- func (o *GetGroupsGroupIDSchedulesOK) GetPayload() []*models.DtoScheduleResponse
- func (o *GetGroupsGroupIDSchedulesOK) IsClientError() bool
- func (o *GetGroupsGroupIDSchedulesOK) IsCode(code int) bool
- func (o *GetGroupsGroupIDSchedulesOK) IsRedirect() bool
- func (o *GetGroupsGroupIDSchedulesOK) IsServerError() bool
- func (o *GetGroupsGroupIDSchedulesOK) IsSuccess() bool
- func (o *GetGroupsGroupIDSchedulesOK) String() string
- type GetGroupsGroupIDSchedulesParams
- func NewGetGroupsGroupIDSchedulesParams() *GetGroupsGroupIDSchedulesParams
- func NewGetGroupsGroupIDSchedulesParamsWithContext(ctx context.Context) *GetGroupsGroupIDSchedulesParamsdeprecated
- func NewGetGroupsGroupIDSchedulesParamsWithHTTPClient(client *http.Client) *GetGroupsGroupIDSchedulesParams
- func NewGetGroupsGroupIDSchedulesParamsWithTimeout(timeout time.Duration) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) SetContext(ctx context.Context)deprecated
- func (o *GetGroupsGroupIDSchedulesParams) SetDate(date *string)
- func (o *GetGroupsGroupIDSchedulesParams) SetDay(day *string)
- func (o *GetGroupsGroupIDSchedulesParams) SetDefaults()
- func (o *GetGroupsGroupIDSchedulesParams) SetGroupID(groupID int64)
- func (o *GetGroupsGroupIDSchedulesParams) SetHTTPClient(client *http.Client)
- func (o *GetGroupsGroupIDSchedulesParams) SetTimeout(timeout time.Duration)
- func (o *GetGroupsGroupIDSchedulesParams) SetWeek(week *string)
- func (o *GetGroupsGroupIDSchedulesParams) SetWeekday(weekday *string)
- func (o *GetGroupsGroupIDSchedulesParams) WithContext(ctx context.Context) *GetGroupsGroupIDSchedulesParamsdeprecated
- func (o *GetGroupsGroupIDSchedulesParams) WithDate(date *string) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithDay(day *string) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithDefaults() *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithGroupID(groupID int64) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithHTTPClient(client *http.Client) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithTimeout(timeout time.Duration) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithWeek(week *string) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WithWeekday(weekday *string) *GetGroupsGroupIDSchedulesParams
- func (o *GetGroupsGroupIDSchedulesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type GetGroupsGroupIDSchedulesReader
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for schedules API.
func (*Client) GetGroupsGroupIDSchedules ¶
func (a *Client) GetGroupsGroupIDSchedules(params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)
GetGroupsGroupIDSchedules gets schedules.
get schedules by group ID.
This method does not support injected context. However, timeout and opentracing contexts are honored whenever enabled.
If you need to pass a specific context, use Client.GetGroupsGroupIDSchedulesContext instead.
func (*Client) GetGroupsGroupIDSchedulesContext ¶
func (a *Client) GetGroupsGroupIDSchedulesContext(ctx context.Context, params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)
GetGroupsGroupIDSchedulesContext gets schedules.
get schedules by group ID.
Do not use the deprecated [GetGroupsGroupIDSchedulesParams.Context] with this method: it would be ignored.
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ContextualTransport)
SetTransport changes the transport on the client
type ClientOption ¶
type ClientOption func(*runtime.ClientOperation)
ClientOption may be used to customize the behavior of Client methods.
type ClientService ¶
type ClientService interface {
// GetGroupsGroupIDSchedules get schedules.
GetGroupsGroupIDSchedules(params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)
// GetGroupsGroupIDSchedulesContext get schedules.
GetGroupsGroupIDSchedulesContext(ctx context.Context, params *GetGroupsGroupIDSchedulesParams, opts ...ClientOption) (*GetGroupsGroupIDSchedulesOK, error)
SetTransport(transport runtime.ContextualTransport)
}
ClientService is the interface for Client methods.
func New ¶
func New(transport runtime.ContextualTransport, formats strfmt.Registry) ClientService
New creates a new schedules API client.
func NewClientWithBasicAuth ¶
func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService
New creates a new schedules API client with basic auth credentials.
It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.
func NewClientWithBearerToken ¶
func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService
New creates a new schedules API client with a bearer token for authentication.
It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.
type GetGroupsGroupIDSchedulesBadRequest ¶
type GetGroupsGroupIDSchedulesBadRequest struct {
Payload *models.DtoErrorResponse
}
GetGroupsGroupIDSchedulesBadRequest describes a response with status code 400, with default header values.
Bad Request
func NewGetGroupsGroupIDSchedulesBadRequest ¶
func NewGetGroupsGroupIDSchedulesBadRequest() *GetGroupsGroupIDSchedulesBadRequest
NewGetGroupsGroupIDSchedulesBadRequest creates a GetGroupsGroupIDSchedulesBadRequest with default headers values
func (*GetGroupsGroupIDSchedulesBadRequest) Code ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) Code() int
Code gets the status code for the get groups group Id schedules bad request response
func (*GetGroupsGroupIDSchedulesBadRequest) Error ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) Error() string
func (*GetGroupsGroupIDSchedulesBadRequest) GetPayload ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) GetPayload() *models.DtoErrorResponse
func (*GetGroupsGroupIDSchedulesBadRequest) IsClientError ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) IsClientError() bool
IsClientError returns true when this get groups group Id schedules bad request response has a 4xx status code
func (*GetGroupsGroupIDSchedulesBadRequest) IsCode ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) IsCode(code int) bool
IsCode returns true when this get groups group Id schedules bad request response a status code equal to that given
func (*GetGroupsGroupIDSchedulesBadRequest) IsRedirect ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) IsRedirect() bool
IsRedirect returns true when this get groups group Id schedules bad request response has a 3xx status code
func (*GetGroupsGroupIDSchedulesBadRequest) IsServerError ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) IsServerError() bool
IsServerError returns true when this get groups group Id schedules bad request response has a 5xx status code
func (*GetGroupsGroupIDSchedulesBadRequest) IsSuccess ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) IsSuccess() bool
IsSuccess returns true when this get groups group Id schedules bad request response has a 2xx status code
func (*GetGroupsGroupIDSchedulesBadRequest) String ¶
func (o *GetGroupsGroupIDSchedulesBadRequest) String() string
type GetGroupsGroupIDSchedulesConflict ¶
type GetGroupsGroupIDSchedulesConflict struct {
Payload *models.DtoErrorResponse
}
GetGroupsGroupIDSchedulesConflict describes a response with status code 409, with default header values.
Conflict
func NewGetGroupsGroupIDSchedulesConflict ¶
func NewGetGroupsGroupIDSchedulesConflict() *GetGroupsGroupIDSchedulesConflict
NewGetGroupsGroupIDSchedulesConflict creates a GetGroupsGroupIDSchedulesConflict with default headers values
func (*GetGroupsGroupIDSchedulesConflict) Code ¶
func (o *GetGroupsGroupIDSchedulesConflict) Code() int
Code gets the status code for the get groups group Id schedules conflict response
func (*GetGroupsGroupIDSchedulesConflict) Error ¶
func (o *GetGroupsGroupIDSchedulesConflict) Error() string
func (*GetGroupsGroupIDSchedulesConflict) GetPayload ¶
func (o *GetGroupsGroupIDSchedulesConflict) GetPayload() *models.DtoErrorResponse
func (*GetGroupsGroupIDSchedulesConflict) IsClientError ¶
func (o *GetGroupsGroupIDSchedulesConflict) IsClientError() bool
IsClientError returns true when this get groups group Id schedules conflict response has a 4xx status code
func (*GetGroupsGroupIDSchedulesConflict) IsCode ¶
func (o *GetGroupsGroupIDSchedulesConflict) IsCode(code int) bool
IsCode returns true when this get groups group Id schedules conflict response a status code equal to that given
func (*GetGroupsGroupIDSchedulesConflict) IsRedirect ¶
func (o *GetGroupsGroupIDSchedulesConflict) IsRedirect() bool
IsRedirect returns true when this get groups group Id schedules conflict response has a 3xx status code
func (*GetGroupsGroupIDSchedulesConflict) IsServerError ¶
func (o *GetGroupsGroupIDSchedulesConflict) IsServerError() bool
IsServerError returns true when this get groups group Id schedules conflict response has a 5xx status code
func (*GetGroupsGroupIDSchedulesConflict) IsSuccess ¶
func (o *GetGroupsGroupIDSchedulesConflict) IsSuccess() bool
IsSuccess returns true when this get groups group Id schedules conflict response has a 2xx status code
func (*GetGroupsGroupIDSchedulesConflict) String ¶
func (o *GetGroupsGroupIDSchedulesConflict) String() string
type GetGroupsGroupIDSchedulesInternalServerError ¶
type GetGroupsGroupIDSchedulesInternalServerError struct {
Payload *models.DtoErrorResponse
}
GetGroupsGroupIDSchedulesInternalServerError describes a response with status code 500, with default header values.
Internal Server Error
func NewGetGroupsGroupIDSchedulesInternalServerError ¶
func NewGetGroupsGroupIDSchedulesInternalServerError() *GetGroupsGroupIDSchedulesInternalServerError
NewGetGroupsGroupIDSchedulesInternalServerError creates a GetGroupsGroupIDSchedulesInternalServerError with default headers values
func (*GetGroupsGroupIDSchedulesInternalServerError) Code ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) Code() int
Code gets the status code for the get groups group Id schedules internal server error response
func (*GetGroupsGroupIDSchedulesInternalServerError) Error ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) Error() string
func (*GetGroupsGroupIDSchedulesInternalServerError) GetPayload ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) GetPayload() *models.DtoErrorResponse
func (*GetGroupsGroupIDSchedulesInternalServerError) IsClientError ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) IsClientError() bool
IsClientError returns true when this get groups group Id schedules internal server error response has a 4xx status code
func (*GetGroupsGroupIDSchedulesInternalServerError) IsCode ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) IsCode(code int) bool
IsCode returns true when this get groups group Id schedules internal server error response a status code equal to that given
func (*GetGroupsGroupIDSchedulesInternalServerError) IsRedirect ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) IsRedirect() bool
IsRedirect returns true when this get groups group Id schedules internal server error response has a 3xx status code
func (*GetGroupsGroupIDSchedulesInternalServerError) IsServerError ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) IsServerError() bool
IsServerError returns true when this get groups group Id schedules internal server error response has a 5xx status code
func (*GetGroupsGroupIDSchedulesInternalServerError) IsSuccess ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) IsSuccess() bool
IsSuccess returns true when this get groups group Id schedules internal server error response has a 2xx status code
func (*GetGroupsGroupIDSchedulesInternalServerError) String ¶
func (o *GetGroupsGroupIDSchedulesInternalServerError) String() string
type GetGroupsGroupIDSchedulesNotFound ¶
type GetGroupsGroupIDSchedulesNotFound struct {
Payload *models.DtoErrorResponse
}
GetGroupsGroupIDSchedulesNotFound describes a response with status code 404, with default header values.
Not Found
func NewGetGroupsGroupIDSchedulesNotFound ¶
func NewGetGroupsGroupIDSchedulesNotFound() *GetGroupsGroupIDSchedulesNotFound
NewGetGroupsGroupIDSchedulesNotFound creates a GetGroupsGroupIDSchedulesNotFound with default headers values
func (*GetGroupsGroupIDSchedulesNotFound) Code ¶
func (o *GetGroupsGroupIDSchedulesNotFound) Code() int
Code gets the status code for the get groups group Id schedules not found response
func (*GetGroupsGroupIDSchedulesNotFound) Error ¶
func (o *GetGroupsGroupIDSchedulesNotFound) Error() string
func (*GetGroupsGroupIDSchedulesNotFound) GetPayload ¶
func (o *GetGroupsGroupIDSchedulesNotFound) GetPayload() *models.DtoErrorResponse
func (*GetGroupsGroupIDSchedulesNotFound) IsClientError ¶
func (o *GetGroupsGroupIDSchedulesNotFound) IsClientError() bool
IsClientError returns true when this get groups group Id schedules not found response has a 4xx status code
func (*GetGroupsGroupIDSchedulesNotFound) IsCode ¶
func (o *GetGroupsGroupIDSchedulesNotFound) IsCode(code int) bool
IsCode returns true when this get groups group Id schedules not found response a status code equal to that given
func (*GetGroupsGroupIDSchedulesNotFound) IsRedirect ¶
func (o *GetGroupsGroupIDSchedulesNotFound) IsRedirect() bool
IsRedirect returns true when this get groups group Id schedules not found response has a 3xx status code
func (*GetGroupsGroupIDSchedulesNotFound) IsServerError ¶
func (o *GetGroupsGroupIDSchedulesNotFound) IsServerError() bool
IsServerError returns true when this get groups group Id schedules not found response has a 5xx status code
func (*GetGroupsGroupIDSchedulesNotFound) IsSuccess ¶
func (o *GetGroupsGroupIDSchedulesNotFound) IsSuccess() bool
IsSuccess returns true when this get groups group Id schedules not found response has a 2xx status code
func (*GetGroupsGroupIDSchedulesNotFound) String ¶
func (o *GetGroupsGroupIDSchedulesNotFound) String() string
type GetGroupsGroupIDSchedulesOK ¶
type GetGroupsGroupIDSchedulesOK struct {
Payload []*models.DtoScheduleResponse
}
GetGroupsGroupIDSchedulesOK describes a response with status code 200, with default header values.
OK
func NewGetGroupsGroupIDSchedulesOK ¶
func NewGetGroupsGroupIDSchedulesOK() *GetGroupsGroupIDSchedulesOK
NewGetGroupsGroupIDSchedulesOK creates a GetGroupsGroupIDSchedulesOK with default headers values
func (*GetGroupsGroupIDSchedulesOK) Code ¶
func (o *GetGroupsGroupIDSchedulesOK) Code() int
Code gets the status code for the get groups group Id schedules o k response
func (*GetGroupsGroupIDSchedulesOK) Error ¶
func (o *GetGroupsGroupIDSchedulesOK) Error() string
func (*GetGroupsGroupIDSchedulesOK) GetPayload ¶
func (o *GetGroupsGroupIDSchedulesOK) GetPayload() []*models.DtoScheduleResponse
func (*GetGroupsGroupIDSchedulesOK) IsClientError ¶
func (o *GetGroupsGroupIDSchedulesOK) IsClientError() bool
IsClientError returns true when this get groups group Id schedules o k response has a 4xx status code
func (*GetGroupsGroupIDSchedulesOK) IsCode ¶
func (o *GetGroupsGroupIDSchedulesOK) IsCode(code int) bool
IsCode returns true when this get groups group Id schedules o k response a status code equal to that given
func (*GetGroupsGroupIDSchedulesOK) IsRedirect ¶
func (o *GetGroupsGroupIDSchedulesOK) IsRedirect() bool
IsRedirect returns true when this get groups group Id schedules o k response has a 3xx status code
func (*GetGroupsGroupIDSchedulesOK) IsServerError ¶
func (o *GetGroupsGroupIDSchedulesOK) IsServerError() bool
IsServerError returns true when this get groups group Id schedules o k response has a 5xx status code
func (*GetGroupsGroupIDSchedulesOK) IsSuccess ¶
func (o *GetGroupsGroupIDSchedulesOK) IsSuccess() bool
IsSuccess returns true when this get groups group Id schedules o k response has a 2xx status code
func (*GetGroupsGroupIDSchedulesOK) String ¶
func (o *GetGroupsGroupIDSchedulesOK) String() string
type GetGroupsGroupIDSchedulesParams ¶
type GetGroupsGroupIDSchedulesParams struct {
// Date.
//
// Specific date (dd-mm-yyyy)
Date *string
// Day.
//
// Relative day
Day *string
// GroupID.
//
// Group ID
GroupID int64
// Week.
//
// Week of schedules
Week *string
// Weekday.
//
// Weekday of schedules
Weekday *string
HTTPClient *http.Client
// contains filtered or unexported fields
}
GetGroupsGroupIDSchedulesParams contains all the parameters to send to the API endpoint
for the get groups group ID schedules operation. Typically these are written to a http.Request.
func NewGetGroupsGroupIDSchedulesParams ¶
func NewGetGroupsGroupIDSchedulesParams() *GetGroupsGroupIDSchedulesParams
NewGetGroupsGroupIDSchedulesParams creates a new GetGroupsGroupIDSchedulesParams object, with the default timeout for this client.
Default values are not hydrated, since defaults are normally applied by the API server side.
To enforce default values in parameter, use SetDefaults or WithDefaults.
func NewGetGroupsGroupIDSchedulesParamsWithContext
deprecated
func NewGetGroupsGroupIDSchedulesParamsWithContext(ctx context.Context) *GetGroupsGroupIDSchedulesParams
NewGetGroupsGroupIDSchedulesParamsWithContext creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a context for a request.
Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.
func NewGetGroupsGroupIDSchedulesParamsWithHTTPClient ¶
func NewGetGroupsGroupIDSchedulesParamsWithHTTPClient(client *http.Client) *GetGroupsGroupIDSchedulesParams
NewGetGroupsGroupIDSchedulesParamsWithHTTPClient creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a custom HTTPClient for a request.
func NewGetGroupsGroupIDSchedulesParamsWithTimeout ¶
func NewGetGroupsGroupIDSchedulesParamsWithTimeout(timeout time.Duration) *GetGroupsGroupIDSchedulesParams
NewGetGroupsGroupIDSchedulesParamsWithTimeout creates a new GetGroupsGroupIDSchedulesParams object with the ability to set a timeout on a request.
func (*GetGroupsGroupIDSchedulesParams) SetContext
deprecated
func (o *GetGroupsGroupIDSchedulesParams) SetContext(ctx context.Context)
SetContext adds the context to the get groups group ID schedules params.
Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.
func (*GetGroupsGroupIDSchedulesParams) SetDate ¶
func (o *GetGroupsGroupIDSchedulesParams) SetDate(date *string)
SetDate adds the date to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetDay ¶
func (o *GetGroupsGroupIDSchedulesParams) SetDay(day *string)
SetDay adds the day to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetDefaults ¶
func (o *GetGroupsGroupIDSchedulesParams) SetDefaults()
SetDefaults hydrates default values in the get groups group ID schedules params (not the query body).
All values with no default are reset to their zero value.
func (*GetGroupsGroupIDSchedulesParams) SetGroupID ¶
func (o *GetGroupsGroupIDSchedulesParams) SetGroupID(groupID int64)
SetGroupID adds the groupId to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetHTTPClient ¶
func (o *GetGroupsGroupIDSchedulesParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetTimeout ¶
func (o *GetGroupsGroupIDSchedulesParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetWeek ¶
func (o *GetGroupsGroupIDSchedulesParams) SetWeek(week *string)
SetWeek adds the week to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) SetWeekday ¶
func (o *GetGroupsGroupIDSchedulesParams) SetWeekday(weekday *string)
SetWeekday adds the weekday to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithContext
deprecated
func (o *GetGroupsGroupIDSchedulesParams) WithContext(ctx context.Context) *GetGroupsGroupIDSchedulesParams
WithContext adds the context to the get groups group ID schedules params.
Deprecated: use the operation call with context to pass the context instead of GetGroupsGroupIDSchedulesParams.
func (*GetGroupsGroupIDSchedulesParams) WithDate ¶
func (o *GetGroupsGroupIDSchedulesParams) WithDate(date *string) *GetGroupsGroupIDSchedulesParams
WithDate adds the date to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithDay ¶
func (o *GetGroupsGroupIDSchedulesParams) WithDay(day *string) *GetGroupsGroupIDSchedulesParams
WithDay adds the day to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithDefaults ¶
func (o *GetGroupsGroupIDSchedulesParams) WithDefaults() *GetGroupsGroupIDSchedulesParams
WithDefaults hydrates default values in the get groups group ID schedules params (not the query body).
All values with no default are reset to their zero value.
func (*GetGroupsGroupIDSchedulesParams) WithGroupID ¶
func (o *GetGroupsGroupIDSchedulesParams) WithGroupID(groupID int64) *GetGroupsGroupIDSchedulesParams
WithGroupID adds the groupID to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithHTTPClient ¶
func (o *GetGroupsGroupIDSchedulesParams) WithHTTPClient(client *http.Client) *GetGroupsGroupIDSchedulesParams
WithHTTPClient adds the HTTPClient to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithTimeout ¶
func (o *GetGroupsGroupIDSchedulesParams) WithTimeout(timeout time.Duration) *GetGroupsGroupIDSchedulesParams
WithTimeout adds the timeout to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithWeek ¶
func (o *GetGroupsGroupIDSchedulesParams) WithWeek(week *string) *GetGroupsGroupIDSchedulesParams
WithWeek adds the week to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WithWeekday ¶
func (o *GetGroupsGroupIDSchedulesParams) WithWeekday(weekday *string) *GetGroupsGroupIDSchedulesParams
WithWeekday adds the weekday to the get groups group ID schedules params.
func (*GetGroupsGroupIDSchedulesParams) WriteToRequest ¶
func (o *GetGroupsGroupIDSchedulesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a runtime.ClientRequest.
type GetGroupsGroupIDSchedulesReader ¶
type GetGroupsGroupIDSchedulesReader struct {
// contains filtered or unexported fields
}
GetGroupsGroupIDSchedulesReader is a Reader for the GetGroupsGroupIDSchedules structure.
func (*GetGroupsGroupIDSchedulesReader) ReadResponse ¶
func (o *GetGroupsGroupIDSchedulesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)
ReadResponse reads a server response into the received o.